# API

```{eval-rst}
.. module:: cuda_zarr
```

Stores:

```{eval-rst}
.. autosummary::
   :toctree: generated/

   RemoteCuFileStore
   CuFileStore
```

Codecs:

```{eval-rst}
.. autosummary::
   :toctree: generated/

   ZstdGPU
```
